@echo OFF
REM Licensed Materials - Property of IBM
REM
REM (C) Copyright IBM Corp. 2011, 2013 All Rights Reserved
REM
REM US Government Users Restricted Rights - Use, duplicate or
REM disclosure restricted by GSA ADP Schedule Contract with
REM IBM Corp.

REM Check if SCDEBUG flag is on

   if "%SCDEBUG%"=="1" (@echo on)

   SET RETCODE=0
   SET BACKUP_DIR=C:\temp\sc_backup
   SET TARGET_DIR=%BACKUP_DIR%
   set TMPDIR=c:\temp\sc_backup
   SET DIRHOME=
   SET JAVAPATH=
   SET VALIDVER="6.3.0"

   SET TPC_HOME=C:\Program Files\ibm\tpc

   if NOT EXIST "%TPC_HOME%\version.txt" (
     SET RETCODE=1
     GOTO EXITWITHSTATUS
   )

   GOTO initializeJava
:initializeJavaReturn
   
   SET LOG=%DIRHOME%\log\SCRestore.log

   REM It's for Defect 190012, specifying a new backup directory.
   REM And the parameter preprocess script is moved into the code StorageControlExt.java.
   SET TARGET_DIR=%~1
   SET BACKUP_DIR=%~2
   
	echo "BACKUP_DIR=%BACKUP_DIR%" >> %LOG% 2>&1
	echo "TARGET_DIR=%TARGET_DIR%" >> %LOG% 2>&1

   set DIRECDIR=%DIRHOME:\"=%
   set DIRECDIR=%DIRECDIR:\\=\%

   if NOT EXIST %TMPDIR% (
       mkdir %TMPDIR%
   )

   SET BACKUPFILE=%TMPDIR%\sc_migrate_options.backup.bat
   SET RESTOREFILE=%TMPDIR%\sc_migrate_options.restore.bat
   
   %JAVAPATH% -DBACKUPDIR="%BACKUP_DIR%" -DBACKUPFILE=%BACKUPFILE% -DRESTOREFILE=%RESTOREFILE% -classpath %CLASSPATH% SCMigrateDB %DIRHOME% "%TPC_HOME%" >> %LOG% 2>&1 
   if ERRORLEVEL 1 (
      SET RETCODE=%ERRORLEVEL%
      call :displayMessage "MIGRATION_FAILED"
      GOTO EXITWITHSTATUS
   )

   if NOT EXIST %RESTOREFILE% (
      SET RETCODE=1
      call :displayMessage "MIGRATION_RESTORE_NOT_FOUND"
      GOTO EXITWITHSTATUS
   )

   REM Check the database.properties file for the current DB location.
   for /f "usebackq tokens=1,2 delims==" %%a in (`type %DIRHOME%\lwi\conf\overrides\database.properties`) do ( 
	if "%%a"=="rcs.DbmsDatabaseAppHome " ( 
		SET DB2HOME=%%b
	) 
   ) 
   
   REM Remove leading spaces from the DB2HOME variable.
   for /f "tokens=* delims= " %%a in ("%DB2HOME%") do set DB2HOME=%%a


   "%DB2HOME%"\bin\db2cmd /w /i /c \%DIRECDIR%\StorageControl\bin\SCMigDBSupport.bat\" %RESTOREFILE%
   if ERRORLEVEL 1 (
      SET RETCODE=1
      call :displayMessage "MIGRATION_RESTORE_FAILED"
      GOTO EXITWITHSTATUS
   )

   GOTO CopyFiles
:CopyFilesReturn

   GOTO EXITWITHSTATUS


:initializeJava
   REGEDIT /E DIR_REG.REG "HKEY_LOCAL_MACHINE\SOFTWARE\IBM\IBM Director Server\CurrentVersion" 

   set VALID_DIRECTOR=0

   if NOT EXIST DIR_REG.REG ( 
      SET RETCODE=1
      call :displayMessage "ISD_NOT_INSTALLED"
      GOTO EXITWITHSTATUS
   ) 

   for /f "usebackq tokens=1,2 delims==" %%a in (`type DIR_REG.REG`) do ( 
    
     if %%a=="Version" ( 
        if %%b GEQ %VALIDVER% ( 
           set VALID_DIRECTOR=1
        ) else (
           call :displayMessage "ISD_NOT_INSTALLED"
           SET RETCODE=1
           GOTO EXITWITHSTATUS
        )
     ) 
     if %%a=="Root" ( 
        SET DIRHOME=%%b
     ) 

   ) 

   SET CLASSPATH=%DIRHOME%\StorageControl\lib\*;%DIRHOME%\lwi\lib\passutils.jar;%DIRHOME%\lwi\lib\lwisecurity.jar
   REM source the javaHome file to get the JAVA_HOME environment variable
   call %DIRHOME%\lwi\conf\javaHome.bat
   SET JAVAPATH="%JAVA_HOME%"\bin\java
   GOTO initializeJavaReturn

:displayMessage
   if %VALID_DIRECTOR% EQU 1 (
     %JAVAPATH% -classpath %CLASSPATH% DisplayMessage %1 %2 %3 >> %LOG% 2>&1
   ) 
   GOTO FINALEOF

:CopyFiles

    echo "Restoring files from %TARGET_DIR% to %DIRHOME%\conf\overrides" >> %LOG% 2>&1
    copy /y "%TARGET_DIR%"\etpc.javaopt   %DIRHOME%\lwi\conf\overrides >> %LOG% 2>&1
    if ERRORLEVEL 1 (
       SET RETCODE=1
       call :displayMessage "SCRESTORE_FAILED"
       GOTO EXITWITHSTATUS
    )

    echo "Restoring files from %TARGET_DIR% to %DIRHOME%\proddata\advmgr" >> %LOG% 2>&1
    copy /y "%TARGET_DIR%"\sc_advmgr.properties %DIRHOME%\proddata\advmgr >> %LOG% 2>&1
    if ERRORLEVEL 1 (
       SET RETCODE=2
       call :displayMessage "SCRESTORE_FAILED"
       GOTO EXITWITHSTATUS
    )
    
    GOTO CopyFilesReturn

:cleanupFiles
   REM Remove the backup and restore files if they exist

   IF EXIST %BACKUPFILE% (
      echo "Deleting %BACKUPFILE%" >> %LOG%
      del /F %BACKUPFILE% >> %LOG% 2>&1
      IF ERRORLEVEL 1 (
         SET RETCODE=1
         call :displayMessage "SCRESTORE_FAILED"
         EXIT /B 1
      )
   )

   IF EXIST %RESTOREFILE% (
      echo "Deleting %RESTOREFILE%" >> %LOG% 2>&1
      del /F %RESTOREFILE% >> %LOG% 2>&1
      IF ERRORLEVEL 1 (
         SET RETCODE=2
         call :displayMessage "SCRESTORE_FAILED"
         EXIT /B 1
      )
   )

   IF ERRORLEVEL 1 (
      SET RETCODE=3
      call :displayMessage "SCRESTORE_FAILED"
      EXIT /B 1
   )

   GOTO cleanupFilesReturn

:EXITWITHSTATUS

    GOTO cleanupFiles
:cleanupFilesReturn

    IF %RETCODE% EQU 0 (
       call :displayMessage "SCRESTORE_SUCCESS"
    )

    echo "RETCODE=%RETCODE%" >> %LOG% 2>&1
    EXIT /B %RETCODE%

:FINALEOF
